Learn R Programming

tidyfst (version 0.8.8)

mutate_when: Conditional update of columns in data.table

Description

mutate_when integrates mutate and case_when in dplyr and make a new tidy verb for data.table. mutate_vars is a super function to do updates in specific columns according to conditions.

Usage

mutate_when(data, when, ...)

mutate_vars(data, .cols = NULL, .func, ...)

Arguments

data

data.frame

when

An object which can be coerced to logical mode

...

Name-value pairs of expressions for mutate_when. Additional parameters to be passed to parameter '.func' in mutate_vars.

.cols

Any types that can be accepted by select_dt.

.func

Function to be run within each column, should return a value or vectors with same length.

Value

data.table

See Also

select_dt, case_when

Examples

Run this code
# NOT RUN {
iris[3:8,]
iris[3:8,] %>%
  mutate_when(Petal.Width == .2,
              one = 1,Sepal.Length=2)

iris %>% mutate_vars("Pe",scale)
iris %>% mutate_vars(is.numeric,scale)
iris %>% mutate_vars(1:2,scale)
iris %>% mutate_vars(.func = as.character)
# }

Run the code above in your browser using DataLab