The number of rows to be printed from the beginning and
end of tables with more than nrow rows.
nrows
The number of rows which will be printed before truncation is enforced.
class
If TRUE, the resulting output will include above each column its storage class (or a self-evident abbreviation thereof).
row.names
If TRUE, row indices will be printed.
col.names
One of three flavours for controlling the display of column names in output. "auto" includes column names above the data, as well as below the table if nrow(x) > 20. "top" excludes this lower register when applicable, and "none" suppresses column names altogether (as well as column classes if class = TRUE.
print.keys
If TRUE, any key and/or index currently assigned to x will be printed prior to the preview of the data.
trunc.cols
If TRUE, only the columns that can be printed in the console without wrapping the columns to new lines will be printed (similar to tibbles).
Value
None. This function is used for its side effect of changing options.
Details
Notice that tidyfst has a slightly different printing default for data.table,
which is it always prints the keys and variable class (not like data.table).
# NOT RUN {iris %>% as.data.table()
print_options(topn = 3,trunc.cols = TRUE)
iris %>% as.data.table()
# set all settings to default in tidyfstprint_options()
iris %>% as.data.table()
# }